{% load i18n horizon %}
<div class="well">
<p>
    {% blocktrans %}This Node Group Template will be created for:{% endblocktrans %}
    <br >
    <b>{% blocktrans %}Plugin{% endblocktrans %}</b>: {{ plugin_name }}
    <br />
    <b>{% blocktrans %}Version{% endblocktrans %}</b>: {{ hadoop_version }}
    <br />
        {% if deprecated %}
    <div class="bs-component">
        <div class="alert alert-dismissable alert-warning">
          <button type="button" class="close" data-dismiss="alert">×</button>
          <h4 translate=""><span class="ng-scope">Warning!</span></h4>
          <p> {% blocktrans %} Version: <b>{{ hadoop_version }}</b>
              of plugin <b>{{ plugin_name }} </b>
              is now deprecated. {% endblocktrans %}
          </p>
        </div>
      </div>
    {% endif %}
</p>
<p>
    {% blocktrans %}The Node Group Template object specifies the processes
        that will be launched on each instance. Check one or more processes.
        When processes are selected, you may set <b>node</b> scoped
        configurations on corresponding tabs.{% endblocktrans %}
</p>
<p>
    {% blocktrans %}You must choose a flavor to determine the size (VCPUs, memory and storage) of all launched VMs.{% endblocktrans %}
</p>
<p>
    {% blocktrans %}Data Processing provides different storage location options. You may choose Ephemeral Drive or a Cinder Volume to be attached to instances.{% endblocktrans %}
</p>
</div>
